@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -51,9 +51,10 @@ using namespace giada::m;
 
 Channel::Channel(int type, int status, int bufferSize)
 : bufferSize     (bufferSize),
-	midiFilter     (-1),
-	pan            (0.5f),
+	midiInFilter   (-1),
 	previewMode    (G_PREVIEW_NONE),
+	pan            (0.5f),
+	armed          (false),
 	type           (type),
 	status         (status),
 	key            (0),
@@ -66,7 +67,6 @@ Channel::Channel(int type, int status, int bufferSize)
 	solo           (false),
 	hasActions     (false),
 	readActions    (false),
-	armed          (false),
 	recStatus      (REC_STOPPED),
 	vChan          (nullptr),
 	guiChannel     (nullptr),
@@ -166,7 +166,7 @@ void Channel::copy(const Channel *src, pthread_mutex_t *pluginMutex)
 /* -------------------------------------------------------------------------- */
 
 
-void Channel::sendMidiLmessage(uint32_t learn, const midimap::message_t &msg)
+void Channel::sendMidiLmessage(uint32_t learn, const midimap::message_t& msg)
 {
 	gu_log("[channel::sendMidiLmessage] learn=%#X, chan=%d, msg=%#X, offset=%d\n",
 		learn, msg.channel, msg.value, msg.offset);
@@ -187,7 +187,7 @@ void Channel::sendMidiLmessage(uint32_t learn, const midimap::message_t &msg)
 /* -------------------------------------------------------------------------- */
 
 
-bool Channel::isPlaying()
+bool Channel::isPlaying() const
 {
 	return status & (STATUS_PLAY | STATUS_ENDING);
 }
@@ -202,7 +202,9 @@ int Channel::writePatch(int i, bool isProject)
 	pch.type            = type;
 	pch.index           = index;
 	pch.size            = guiChannel->getSize();
+	pch.name            = name;
 	pch.key             = key;
+	pch.armed           = armed;
 	pch.column          = guiChannel->getColumnIndex();
 	pch.mute            = mute;
 	pch.mute_s          = mute_s;
@@ -216,6 +218,7 @@ int Channel::writePatch(int i, bool isProject)
 	pch.midiInArm       = midiInArm;
 	pch.midiInVolume    = midiInVolume;
 	pch.midiInMute      = midiInMute;
+	pch.midiInFilter    = midiInFilter;
 	pch.midiInSolo      = midiInSolo;
 	pch.midiOutL        = midiOutL;
 	pch.midiOutLplaying = midiOutLplaying;
@@ -224,7 +227,7 @@ int Channel::writePatch(int i, bool isProject)
 
 	for (unsigned i=0; i<recorder::global.size(); i++) {
 		for (unsigned k=0; k<recorder::global.at(i).size(); k++) {
-			recorder::action *action = recorder::global.at(i).at(k);
+			recorder::action* action = recorder::global.at(i).at(k);
 			if (action->chan == index) {
 				patch::action_t pac;
 				pac.type   = action->type;
@@ -240,7 +243,7 @@ int Channel::writePatch(int i, bool isProject)
 
 	unsigned numPlugs = pluginHost::countPlugins(pluginHost::CHANNEL, this);
 	for (unsigned i=0; i<numPlugs; i++) {
-		Plugin *pPlugin = pluginHost::getPluginByIndex(i, pluginHost::CHANNEL, this);
+		Plugin* pPlugin = pluginHost::getPluginByIndex(i, pluginHost::CHANNEL, this);
 		patch::plugin_t pp;
 		pp.path   = pPlugin->getUniqueId();
 		pp.bypass = pPlugin->isBypassed();
@@ -262,13 +265,15 @@ int Channel::writePatch(int i, bool isProject)
 /* -------------------------------------------------------------------------- */
 
 
-int Channel::readPatch(const string &path, int i, pthread_mutex_t *pluginMutex,
+int Channel::readPatch(const string& path, int i, pthread_mutex_t* pluginMutex,
 	int samplerate, int rsmpQuality)
 {
 	int ret = 1;
-	patch::channel_t *pch = &patch::channels.at(i);
+	patch::channel_t* pch = &patch::channels.at(i);
 	key             = pch->key;
+	armed           = pch->armed;
 	type            = pch->type;
+	name            = pch->name;
 	index           = pch->index;
 	mute            = pch->mute;
 	mute_s          = pch->mute_s;
@@ -281,34 +286,44 @@ int Channel::readPatch(const string &path, int i, pthread_mutex_t *pluginMutex,
 	midiInKill      = pch->midiInKill;
 	midiInVolume    = pch->midiInVolume;
 	midiInMute      = pch->midiInMute;
+	midiInFilter    = pch->midiInFilter;
 	midiInSolo      = pch->midiInSolo;
 	midiOutL        = pch->midiOutL;
 	midiOutLplaying = pch->midiOutLplaying;
 	midiOutLmute    = pch->midiOutLmute;
 	midiOutLsolo    = pch->midiOutLsolo;
 
-	for (unsigned k=0; k<pch->actions.size(); k++) {
-		patch::action_t *ac = &pch->actions.at(k);
-		recorder::rec(index, ac->type, ac->frame, ac->iValue, ac->fValue);
+	for (const patch::action_t& ac : pch->actions) {
+		recorder::rec(index, ac.type, ac.frame, ac.iValue, ac.fValue);
 		hasActions = true;
 	}
 
 #ifdef WITH_VST
 
-	for (unsigned k=0; k<pch->plugins.size(); k++) {
-		patch::plugin_t *ppl = &pch->plugins.at(k);
-		Plugin *plugin = pluginHost::addPlugin(ppl->path, pluginHost::CHANNEL,
+	for (const patch::plugin_t& ppl : pch->plugins) {
+		
+		Plugin* plugin = pluginHost::addPlugin(ppl.path, pluginHost::CHANNEL,
 			pluginMutex, this);
+		
 		if (plugin == nullptr) {
 			ret &= 0;
 			continue;
 		}
-		plugin->setBypass(ppl->bypass);
-		for (unsigned j=0; j<ppl->params.size(); j++)
-			plugin->setParameter(j, ppl->params.at(j));
-		plugin->midiInParams.clear();
-		for (unsigned j=0; j<ppl->midiInParams.size(); j++)
-			plugin->midiInParams.push_back(ppl->midiInParams.at(j));
+
+		plugin->setBypass(ppl.bypass);
+		
+		for (unsigned j=0; j<ppl.params.size(); j++)
+			plugin->setParameter(j, ppl.params.at(j));
+		
+		/* Don't fill Channel::midiInParam if Patch::midiInParams are 0: it would
+		wipe out the current default 0x0 values. */
+
+		if (!ppl.midiInParams.empty()) {
+			plugin->midiInParams.clear();
+			for (uint32_t midiInParam : ppl.midiInParams)
+				plugin->midiInParams.push_back(midiInParam);
+		}
+
 		ret &= 1;
 	}
 
@@ -372,10 +387,32 @@ void Channel::sendMidiLplay()
 /* -------------------------------------------------------------------------- */
 
 
-void Channel::receiveMidi(uint32_t msg)
+void Channel::receiveMidi(const MidiEvent& midiEvent)
 {
 }
 
+
+/* -------------------------------------------------------------------------- */
+
+
+void Channel::setMidiInFilter(int c)
+{
+	midiInFilter = c;
+}
+
+
+int Channel::getMidiInFilter() const
+{
+	return midiInFilter;
+}
+
+
+bool Channel::isMidiInAllowed(int c) const
+{
+	return midiInFilter == -1 || midiInFilter == c;
+}
+
+
 /* -------------------------------------------------------------------------- */
 
 
@@ -391,7 +428,7 @@ void Channel::setPan(float v)
 }
 
 
-float Channel::getPan()
+float Channel::getPan() const
 {
 	return pan;
 }
@@ -420,7 +457,7 @@ void Channel::setPreviewMode(int m)
 }
 
 
-bool Channel::isPreview()
+bool Channel::isPreview() const
 {
 	return previewMode != G_PREVIEW_NONE;
 }
@@ -429,6 +466,36 @@ bool Channel::isPreview()
 /* -------------------------------------------------------------------------- */
 
 
+void Channel::setArmed(bool b)
+{
+	armed = b;
+}
+
+
+bool Channel::isArmed() const
+{
+	return armed;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+std::string Channel::getName() const
+{
+	return name;
+}
+
+
+void Channel::setName(const std::string& s)
+{
+	name = s;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
 #ifdef WITH_VST
 
 juce::MidiBuffer &Channel::getPluginMidiEvents()
