@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -33,6 +33,7 @@
 #include <string>
 #include <pthread.h>
 #include "midiMapConf.h"
+#include "midiEvent.h"
 #include "recorder.h"
 
 #ifdef WITH_VST
@@ -49,34 +50,6 @@ class Channel
 {
 protected:
 
-#ifdef WITH_VST
-
-	/* MidiBuffer contains MIDI events. When ready, events are sent to
-	 * each plugin in the channel. This is available for any kind of
-	 * channel, but it makes sense only for MIDI channels. */
-
-	juce::MidiBuffer midiBuffer;
-
-#endif
-
-	/* bufferSize
-	 * size of every buffer in this channel (vChan, pChan) */
-
-	int bufferSize;
-
-  /* midiFilter
-  Which MIDI channel should be filtered out when receiving MIDI messages. -1
-  means 'all'. */
-
-  int midiFilter;
-
-	float pan;
-
-	/* previewMode
-	Whether the channel is in audio preview mode or not. */
-
-	int previewMode;
-
 	/* sendMidiLMessage
 	Composes a MIDI message by merging bytes from MidiMap conf class, and sends it 
 	to KernelMidi. */
@@ -88,6 +61,36 @@ protected:
 
 	float calcPanning(int ch);
 
+#ifdef WITH_VST
+
+	/* MidiBuffer contains MIDI events. When ready, events are sent to each plugin 
+	in the channel. This is available for any kind of channel, but it makes sense 
+	only for MIDI channels. */
+
+	juce::MidiBuffer midiBuffer;
+
+#endif
+
+	/* bufferSize
+	Size of every buffer in this channel (vChan, pChan) */
+
+	int bufferSize;
+
+  /* midiInFilter
+  Which MIDI channel should be filtered out when receiving MIDI messages. -1
+  means 'all'. */
+
+  int midiInFilter;
+
+	/* previewMode
+	Whether the channel is in audio preview mode or not. */
+
+	int previewMode;
+
+	float pan;
+	bool armed;
+	std::string name;
+
 public:
 
 	Channel(int type, int status, int bufferSize);
@@ -95,12 +98,12 @@ public:
 	virtual ~Channel();
 
 	/* copy
-	 * Make a shallow copy (no vChan/pChan allocation) of another channel. */
+	Makes a shallow copy (no vChan/pChan allocation) of another channel. */
 
 	virtual void copy(const Channel* src, pthread_mutex_t* pluginMutex) = 0;
 
 	/* readPatch
-	 * Fill channel with data from patch. */
+	Fills channel with data from patch. */
 
 	virtual int readPatch(const std::string& basePath, int i,
     pthread_mutex_t* pluginMutex, int samplerate, int rsmpQuality);
@@ -127,54 +130,53 @@ public:
 			bool mixerIsRunning, bool forceStart, bool isUserGenerated) = 0;
 
 	/* stop
-	 * action to do when channel is stopped normally (via key or MIDI). */
+	What to do when channel is stopped normally (via key or MIDI). */
 
 	virtual void stop() = 0;
 
 	/* kill
-	 * action to do when channel stops abruptly. */
+	What to do when channel stops abruptly. */
 
 	virtual void kill(int frame) = 0;
 
 	/* mute
-	 * action to do when channel is muted. If internal == true, set
-	 * internal mute without altering main mute. */
+	What to do when channel is muted. If internal == true, set internal mute 
+	without altering main mute. */
 
 	virtual void setMute  (bool internal) = 0;
 	virtual void unsetMute(bool internal) = 0;
 
 	/* empty
-	 * free any associated resources (e.g. waveform for SAMPLE). */
+	Frees any associated resources (e.g. waveform for SAMPLE). */
 
 	virtual void empty() = 0;
 
 	/* stopBySeq
-	 * action to do when channel is stopped by sequencer. */
+	What to do when channel is stopped by sequencer. */
 
 	virtual void stopBySeq(bool chansStopOnSeqHalt) = 0;
 
 	/* quantize
-	 * start channel according to quantizer. Index = array index of
-	 * mixer::channels, used by recorder. LocalFrame = frame within the current
-   * buffer.  */
+	Starts channel according to quantizer. Index = array index of mixer::channels, 
+	used by recorder. LocalFrame = frame within the current buffer.  */
 
 	virtual void quantize(int index, int localFrame) = 0;
 
 	/* onZero
-	 * action to do when frame goes to zero, i.e. sequencer restart. */
+	What to do when frame goes to zero, i.e. sequencer restart. */
 
 	virtual void onZero(int frame, bool recsStopOnChanHalt) = 0;
 
 	/* onBar
-	 * action to do when a bar has passed. */
+	What to do when a bar has passed. */
 
 	virtual void onBar(int frame) = 0;
 
 	/* parseAction
-	 * do something on a recorded action. Parameters:
-	 * action *a   - action to parse
-	 * localFrame  - frame number of the processed buffer
-	 * globalFrame - actual frame in Mixer */
+	Does something on a recorded action. Parameters:
+		- action *a   - action to parse
+	  - localFrame  - frame number of the processed buffer
+	  - globalFrame - actual frame in Mixer */
 
 	 // TODO - quantize is useless!
 
@@ -182,7 +184,7 @@ public:
     int globalFrame, int quantize, bool mixerIsRunning) = 0;
 
 	/* rewind
-	 * rewind channel when rewind button is pressed. */
+	Rewinds channel when rewind button is pressed. */
 
 	virtual void rewind() = 0;
 
@@ -199,15 +201,15 @@ public:
 	virtual bool canInputRec() = 0;
 
 	/* writePatch
-	 * Fill a patch with channel values. Returns the index of the last
-	 * Patch::channel_t added. */
+	Fills a patch with channel values. Returns the index of the last 
+	Patch::channel_t added. */
 
 	virtual int writePatch(int i, bool isProject);
 
 	/* receiveMidi
-	 * Receives and processes midi messages from external devices. */
+	Receives and processes midi messages from external devices. */
 
-	virtual void receiveMidi(uint32_t msg);
+	virtual void receiveMidi(const giada::m::MidiEvent& midiEvent);
 
 	/* allocBuffers
 	Mandatory method to allocate memory for internal buffers. Call it after the
@@ -215,7 +217,43 @@ public:
 
 	virtual bool allocBuffers();
 
-	/* ------------------------------------------------------------------------ */
+	bool isPlaying() const;
+	float getPan() const;
+	bool isArmed() const;
+	std::string getName() const;
+	bool isPreview() const;
+	int getMidiInFilter() const;
+
+	/* isMidiAllowed
+	Given a MIDI channel 'c' tells whether this channel should be allowed to receive
+	and process MIDI events on MIDI channel 'c'. */
+
+	bool isMidiInAllowed(int c) const;
+
+	/* sendMidiL*
+	 * send MIDI lightning events to a physical device. */
+
+	void sendMidiLmute();
+	void sendMidiLsolo();
+	void sendMidiLplay();
+
+	void setPan(float v);
+	void setArmed(bool b);
+	void setName(const std::string& s);
+	void setPreviewMode(int m);
+	void setMidiInFilter(int c);
+
+#ifdef WITH_VST
+
+	/* getPluginMidiEvents
+	 * Return a reference to midiBuffer stack. This is available for any kind of
+	 * channel, but it makes sense only for MIDI channels. */
+
+	juce::MidiBuffer& getPluginMidiEvents();
+
+	void clearMidiBuffer();
+
+#endif
 
 	int    index;                 // unique id
 	int    type;                  // midi or sample
@@ -230,7 +268,6 @@ public:
 	bool   solo;
   bool   hasActions;            // has something recorded
   bool   readActions;           // read what's recorded
-	bool   armed;                 // armed for recording
 	int 	 recStatus;             // status of recordings (waiting, ending, ...)
 	float* vChan;                 // virtual channel
   geChannel* guiChannel;        // pointer to a gChannel object, part of the GUI
@@ -260,38 +297,6 @@ public:
   std::vector <Plugin*> plugins;
 #endif
 
-
-	/* ------------------------------------------------------------------------ */
-
-	/* isPlaying
-	 * tell wether the channel is playing or is stopped. */
-
-	bool isPlaying();
-
-	/* sendMidiL*
-	 * send MIDI lightning events to a physical device. */
-
-	void sendMidiLmute();
-	void sendMidiLsolo();
-	void sendMidiLplay();
-
-	void setPan(float v);
-	float getPan();
-
-	void setPreviewMode(int m);
-	bool isPreview();
-
-#ifdef WITH_VST
-
-	/* getPluginMidiEvents
-	 * Return a reference to midiBuffer stack. This is available for any kind of
-	 * channel, but it makes sense only for MIDI channels. */
-
-	juce::MidiBuffer& getPluginMidiEvents();
-
-	void clearMidiBuffer();
-
-#endif
 };
 
 
