@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -46,10 +46,10 @@
 
 /* -- version --------------------------------------------------------------- */
 #define G_APP_NAME      "Giada"
-#define G_VERSION_STR   "0.14.3"
+#define G_VERSION_STR   "0.14.5"
 #define G_VERSION_MAJOR 0
 #define G_VERSION_MINOR 14
-#define G_VERSION_PATCH 3
+#define G_VERSION_PATCH 5
 
 #define CONF_FILENAME "giada.conf"
 
@@ -140,31 +140,32 @@
 	#define G_DEFAULT_SOUNDSYS 	G_SYS_API_CORE
 #endif
 
-#define G_DEFAULT_SOUNDDEV_OUT    0      // FIXME - please override with rtAudio::getDefaultDevice (or similar)
-#define G_DEFAULT_SOUNDDEV_IN    -1      // no recording by default: input disabled
-#define G_DEFAULT_MIDI_SYSTEM     0
-#define G_DEFAULT_MIDI_PORT_IN   -1
-#define G_DEFAULT_MIDI_PORT_OUT  -1
-#define G_DEFAULT_SAMPLERATE      44100
-#define G_DEFAULT_BUFSIZE         1024
-#define G_DEFAULT_DELAYCOMP       0
-#define G_DEFAULT_BIT_DEPTH       32     // float
-#define G_DEFAULT_AUDIO_CHANS     2      // stereo for internal processing
-#define G_DEFAULT_VOL             1.0f
-#define G_DEFAULT_PITCH           1.0f
-#define G_DEFAULT_BOOST           1.0f
-#define G_DEFAULT_OUT_VOL         1.0f
-#define G_DEFAULT_IN_VOL          1.0f
-#define G_DEFAULT_CHANMODE       SINGLE_BASIC
-#define G_DEFAULT_BPM             120.0f
-#define G_DEFAULT_BEATS           4
-#define G_DEFAULT_BARS            1
-#define G_DEFAULT_QUANTIZE        0      // quantizer off
-#define G_DEFAULT_FADEOUT_STEP    0.01f  // micro-fadeout speed
-#define G_DEFAULT_COLUMN_WIDTH    380
-#define G_DEFAULT_PATCH_NAME      "(default patch)"
-#define G_DEFAULT_MIDI_INPUT_UI_W 300
-#define G_DEFAULT_MIDI_INPUT_UI_H 350
+#define G_DEFAULT_SOUNDDEV_OUT     0      // FIXME - please override with rtAudio::getDefaultDevice (or similar)
+#define G_DEFAULT_SOUNDDEV_IN     -1      // no recording by default: input disabled
+#define G_DEFAULT_MIDI_SYSTEM      0
+#define G_DEFAULT_MIDI_PORT_IN    -1
+#define G_DEFAULT_MIDI_PORT_OUT   -1
+#define G_DEFAULT_SAMPLERATE       44100
+#define G_DEFAULT_BUFSIZE          1024
+#define G_DEFAULT_DELAYCOMP        0
+#define G_DEFAULT_BIT_DEPTH        32     // float
+#define G_DEFAULT_AUDIO_CHANS      2      // stereo for internal processing
+#define G_DEFAULT_VOL              1.0f
+#define G_DEFAULT_PITCH            1.0f
+#define G_DEFAULT_BOOST            1.0f
+#define G_DEFAULT_OUT_VOL          1.0f
+#define G_DEFAULT_IN_VOL           1.0f
+#define G_DEFAULT_CHANMODE         SINGLE_BASIC
+#define G_DEFAULT_BPM              120.0f
+#define G_DEFAULT_BEATS            4
+#define G_DEFAULT_BARS             1
+#define G_DEFAULT_QUANTIZE         0      // quantizer off
+#define G_DEFAULT_FADEOUT_STEP     0.01f  // micro-fadeout speed
+#define G_DEFAULT_COLUMN_WIDTH     380
+#define G_DEFAULT_PATCH_NAME       "(default patch)"
+#define G_DEFAULT_MIDI_INPUT_UI_W  300
+#define G_DEFAULT_MIDI_INPUT_UI_H  350
+#define G_DEFAULT_MIDI_ACTION_SIZE 8192   // frames
 
 
 
@@ -257,6 +258,7 @@
 #define WID_SAMPLE_EDITOR -8
 #define WID_FX            -9
 #define WID_KEY_GRABBER   -10
+#define WID_SAMPLE_NAME   -11
 
 
 
@@ -359,6 +361,7 @@ const int MIDI_CHANS[16] = {
 #define PATCH_KEY_CHANNEL_TYPE                 "type"
 #define PATCH_KEY_CHANNEL_INDEX                "index"
 #define PATCH_KEY_CHANNEL_SIZE                 "size"
+#define PATCH_KEY_CHANNEL_NAME                 "name"
 #define PATCH_KEY_CHANNEL_COLUMN               "column"
 #define PATCH_KEY_CHANNEL_MUTE                 "mute"
 #define PATCH_KEY_CHANNEL_MUTE_S               "mute_s"
@@ -372,6 +375,7 @@ const int MIDI_CHANS[16] = {
 #define PATCH_KEY_CHANNEL_MIDI_IN_ARM          "midi_in_arm"
 #define PATCH_KEY_CHANNEL_MIDI_IN_VOLUME       "midi_in_volume"
 #define PATCH_KEY_CHANNEL_MIDI_IN_MUTE         "midi_in_mute"
+#define PATCH_KEY_CHANNEL_MIDI_IN_FILTER       "midi_in_filter"
 #define PATCH_KEY_CHANNEL_MIDI_IN_SOLO         "midi_in_solo"
 #define PATCH_KEY_CHANNEL_MIDI_OUT_L           "midi_out_l"
 #define PATCH_KEY_CHANNEL_MIDI_OUT_L_PLAYING   "midi_out_l_playing"
@@ -392,6 +396,7 @@ const int MIDI_CHANS[16] = {
 #define PATCH_KEY_CHANNEL_MIDI_OUT_CHAN        "midi_out_chan"
 #define PATCH_KEY_CHANNEL_PLUGINS              "plugins"
 #define PATCH_KEY_CHANNEL_ACTIONS              "actions"
+#define PATCH_KEY_CHANNEL_ARMED                "armed"
 #define PATCH_KEY_ACTION_TYPE                  "type"
 #define PATCH_KEY_ACTION_FRAME                 "frame"
 #define PATCH_KEY_ACTION_F_VALUE               "f_value"
@@ -426,6 +431,8 @@ const int MIDI_CHANS[16] = {
 #define CONF_KEY_LAST_MIDIMAP             "last_midimap"
 #define CONF_KEY_MIDI_SYNC                "midi_sync"
 #define CONF_KEY_MIDI_TC_FPS              "midi_tc_fps"
+#define CONF_KEY_MIDI_IN                  "midi_in"
+#define CONF_KEY_MIDI_IN_FILTER           "midi_in_filter"
 #define CONF_KEY_MIDI_IN_REWIND           "midi_in_rewind"
 #define CONF_KEY_MIDI_IN_START_STOP       "midi_in_start_stop"
 #define CONF_KEY_MIDI_IN_ACTION_REC       "midi_in_action_rec"
@@ -479,6 +486,8 @@ const int MIDI_CHANS[16] = {
 #define CONF_KEY_BEATS_Y                  "beats_y"
 #define CONF_KEY_ABOUT_X                  "about_x"
 #define CONF_KEY_ABOUT_Y                  "about_y"
+#define CONF_KEY_NAME_X                   "name_x"
+#define CONF_KEY_NAME_Y                   "name_y"
 #define CONF_KEY_PLUGIN_CHOOSER_X         "plugin_chooser_x"
 #define CONF_KEY_PLUGIN_CHOOSER_Y         "plugin_chooser_y"
 #define CONF_KEY_PLUGIN_CHOOSER_W         "plugin_chooser_w"
