@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -64,7 +64,7 @@ namespace
 {
 #ifdef WITH_VST
 
-int readPatchPlugins(vector<patch::plugin_t> *list, int type)
+int readPatchPlugins(vector<patch::plugin_t>* list, int type)
 {
 	int ret = 1;
 	for (unsigned i=0; i<list->size(); i++) {
@@ -115,15 +115,13 @@ int getNewChanIndex()
 /* -------------------------------------------------------------------------- */
 
 
-bool uniqueSampleName(SampleChannel* ch, const string& name)
+bool uniqueSamplePath(const SampleChannel* skip, const string& path)
 {
-	for (unsigned i=0; i<mixer::channels.size(); i++) {
-		if (ch == mixer::channels.at(i))  // skip itself
+	for (const Channel* ch : mixer::channels) {
+		if (skip == ch || ch->type != CHANNEL_SAMPLE) // skip itself and MIDI channels
 			continue;
-		if (mixer::channels.at(i)->type != CHANNEL_SAMPLE)
-			continue;
-		SampleChannel* other = (SampleChannel*) mixer::channels.at(i);
-		if (other->wave != nullptr && name == other->wave->getName())
+		const SampleChannel* sch = static_cast<const SampleChannel*>(ch);
+		if (sch->wave != nullptr && path == sch->wave->getPath())
 			return false;
 	}
 	return true;
@@ -276,6 +274,7 @@ void readPatch()
 	clock::setBars(patch::bars);
 	clock::setBeats(patch::beats);
 	clock::setQuantize(patch::quantize);
+	clock::updateFrameBars();
 	mixer::metronome = patch::metronome;
 
 #ifdef WITH_VST
@@ -285,10 +284,12 @@ void readPatch()
 
 #endif
 
-	/* rewind and update frames in Mixer (it's essential) */
+	/* Rewind and update frames in Mixer. Also alloc new space in the virtual
+	input buffer, in case the patch has a sequencer size != default one (which is
+	very likely). */
 
 	mixer::rewind();
-	clock::updateFrameBars();
+	mixer::allocVirtualInput(clock::getTotalFrames());
 	mixer::ready = true;
 }
 
@@ -323,26 +324,19 @@ bool startInputRec()
 
 		Wave* wave = nullptr;
 		int result = waveManager::createEmpty(clock::getTotalFrames(), 
-			conf::samplerate, string("TAKE-" + gu_toString(patch::lastTakeId)), &wave); 
+			conf::samplerate, string("TAKE-" + gu_iToString(patch::lastTakeId)), &wave); 
 		if (result != G_RES_OK) {
 			gu_log("[startInputRec] unable to allocate new Wave in chan %d!\n",
 				ch->index);
 			continue;
 		}
 
-		ch->pushWave(wave, false);  // false: don't generate name, we provide it
-
-		/* Increase lastTakeId until the sample name TAKE-[n] is unique. */
-
-		while (!uniqueSampleName(ch, ch->wave->getName())) {
-			patch::lastTakeId++;
-			ch->wave->setName("TAKE-" + gu_toString(patch::lastTakeId));
-		}
+		ch->pushWave(wave);
+		ch->setName("TAKE-" + gu_iToString(patch::lastTakeId++)); // Increase lastTakeId 
+		channelsReady++;
 
 		gu_log("[startInputRec] start input recs using chan %d with size %d "
 			"frame=%d\n", ch->index, clock::getTotalFrames(), mixer::inputTracker);
-
-		channelsReady++;
 	}
 
 	if (channelsReady > 0) {
@@ -375,7 +369,7 @@ bool hasArmedSampleChannels()
 {
 	for (unsigned i=0; i<mixer::channels.size(); i++) {
 		Channel *ch = mixer::channels.at(i);
-		if (ch->type == CHANNEL_SAMPLE && ch->armed)
+		if (ch->type == CHANNEL_SAMPLE && ch->isArmed())
 			return true;
 	}
 	return false;
