@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -65,6 +65,7 @@ struct channel_t
 	int         type;
 	int         index;
 	int         size;
+	std::string name;
 	int         column;
 	int         mute;
 	int         mute_s;
@@ -79,10 +80,12 @@ struct channel_t
 	uint32_t    midiInVolume;
 	uint32_t    midiInMute;
 	uint32_t    midiInSolo;
+	int         midiInFilter;
 	bool        midiOutL;
 	uint32_t    midiOutLplaying;
 	uint32_t    midiOutLmute;
 	uint32_t    midiOutLsolo;
+	bool        armed;
 	// sample channel
 	std::string samplePath;
 	int         key;
