@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -61,6 +61,7 @@ SampleChannel::SampleChannel(int bufferSize, bool inputMonitor)
 		boost            (G_DEFAULT_BOOST),
 		pitch            (G_DEFAULT_PITCH),
 		trackerPreview   (0),
+		shift            (0),
 		wave             (nullptr),
 		tracker          (0),
 		mode             (G_DEFAULT_CHANMODE),
@@ -155,23 +156,9 @@ void SampleChannel::copy(const Channel* _src, pthread_mutex_t* pluginMutex)
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::generateUniqueSampleName()
-{
-	string oldName = wave->getName();
-	int k = 0;
-	while (!mh::uniqueSampleName(this, wave->getName())) {
-		wave->setName(oldName + "-" + gu_toString(k));
-		k++;
-	}
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
 void SampleChannel::clear()
 {
-	/** TODO - these memsets can be done only if status PLAY (if below),
+	/** TODO - these memsets may be done only if status PLAY (if below),
 	 * but it would require extra clearPChan calls when samples stop */
 
 	std::memset(vChan, 0, sizeof(float) * bufferSize);
@@ -261,15 +248,6 @@ void SampleChannel::onBar(int frame)
 /* -------------------------------------------------------------------------- */
 
 
-int SampleChannel::save(const char* path)
-{
-	return waveManager::save(wave, path);
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
 void SampleChannel::setBegin(int f)
 {
 	/* TODO - Opaque channel's count - everything in SampleChannel should be
@@ -357,6 +335,13 @@ int SampleChannel::getTrackerPreview() const
 /* -------------------------------------------------------------------------- */
 
 
+int SampleChannel::getShift() const { return shift; }
+void SampleChannel::setShift(int s) { shift = s; }
+
+
+/* -------------------------------------------------------------------------- */
+
+
 void SampleChannel::setPitch(float v)
 {
 	if (v > G_MAX_PITCH)
@@ -852,15 +837,14 @@ void SampleChannel::empty()
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::pushWave(Wave* w, bool generateName)
+void SampleChannel::pushWave(Wave* w)
 {
 	sendMidiLplay();     // FIXME - why here?!?!
 	wave   = w;
 	status = STATUS_OFF;
 	begin  = 0;
 	end    = (wave->getSize() - 1) * wave->getChannels(); // TODO - Opaque channels' count
-	if (generateName)
-		generateUniqueSampleName();
+	name   = wave->getBasename();
 }
 
 
@@ -990,15 +974,15 @@ void SampleChannel::stop()
 /* -------------------------------------------------------------------------- */
 
 
-int SampleChannel::readPatch(const string &basePath, int i,
-		pthread_mutex_t *pluginMutex, int samplerate, int rsmpQuality)
+int SampleChannel::readPatch(const string& basePath, int i,
+		pthread_mutex_t* pluginMutex, int samplerate, int rsmpQuality)
 {
 	/* load channel's data first: if the sample is missing or wrong, the channel
 	 * is not completely blank. */
 
 	Channel::readPatch("", i, pluginMutex, samplerate, rsmpQuality);
 
-	patch::channel_t *pch = &patch::channels.at(i);
+	const patch::channel_t* pch = &patch::channels.at(i);
 
 	mode              = pch->mode;
 	boost             = pch->boost;
@@ -1008,13 +992,14 @@ int SampleChannel::readPatch(const string &basePath, int i,
 	midiInPitch       = pch->midiInPitch;
   inputMonitor      = pch->inputMonitor;
 
-  Wave *w = nullptr;
+  Wave* w = nullptr;
   int res = waveManager::create(basePath + pch->samplePath, &w); 
 
 	if (res == G_RES_OK) {
 		pushWave(w);
+		setName(pch->name);
 		setBegin(pch->begin);
-		setEnd  (pch->end);
+		setEnd(pch->end);
 		setPitch(pch->pitch);
 	}
 	else {
