@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -31,6 +31,7 @@
 #include <cstring>  // memcpy
 #include "../utils/fs.h"
 #include "../utils/log.h"
+#include "../utils/string.h"
 #include "const.h"
 #include "wave.h"
 
@@ -57,8 +58,7 @@ Wave::Wave(float* data, int size, int channels, int rate, int bits,
   m_bits    (bits),
   m_logical (false),
   m_edited  (false),
-  m_path    (path),
-  m_name    (gu_stripExt(gu_basename(path)))
+  m_path    (path)
 {
 }	
 
@@ -83,8 +83,7 @@ Wave::Wave(const Wave& other)
   m_bits    (other.m_bits),	
 	m_logical (true),   // a cloned wave does not exist on disk
 	m_edited  (false),
-	m_path    (other.m_path),
-	m_name    (other.m_name)
+	m_path    (other.m_path)
 {
 	m_data = new float[m_size];
 	memcpy(m_data, other.m_data, m_size * sizeof(float));
@@ -126,25 +125,9 @@ string Wave::getBasename(bool ext) const
 /* -------------------------------------------------------------------------- */
 
 
-void Wave::setName(const string& n)
-{
-	string ext = gu_getExt(m_path);
-	m_name = gu_stripExt(gu_basename(n));
-	m_path = gu_dirname(m_path) + G_SLASH + m_name + "." + ext;
-	m_logical  = true;
-
-	/* A wave with updated m_name must become logical, since the underlying file
-	does not exist yet. */
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
 int Wave::getRate() const { return m_rate; }
 int Wave::getChannels() const { return m_channels; }
 std::string Wave::getPath() const { return m_path; }
-std::string Wave::getName() const { return m_name; }
 float* Wave::getData() const { return m_data; }
 int Wave::getSize() const { return m_size / m_channels; }
 int Wave::getBits() const { return m_bits; }
@@ -164,6 +147,15 @@ int Wave::getDuration() const
 /* -------------------------------------------------------------------------- */
 
 
+std::string Wave::getExtension() const
+{
+	return gu_getExt(m_path);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
 float* Wave::getFrame(int f) const
 {
 	assert(f >= 0);
@@ -179,7 +171,6 @@ float* Wave::getFrame(int f) const
 
 void Wave::setRate(int v) { m_rate = v; }
 void Wave::setChannels(int v) { m_channels = v; }
-void Wave::setPath(const string& p) { m_path = p; }
 void Wave::setLogical(bool l) { m_logical = l; }
 void Wave::setEdited(bool e) { m_edited = e; }
 
@@ -187,6 +178,20 @@ void Wave::setEdited(bool e) { m_edited = e; }
 /* -------------------------------------------------------------------------- */
 
 
+void Wave::setPath(const string& p, int id) 
+{ 
+	if (id == -1)
+		m_path = p; 
+	else 
+		m_path = gu_stripExt(p) + "-" + gu_iToString(id) + "." + gu_getExt(p);
+
+
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
 void Wave::setData(float* d, int size) 
 { 
 	m_data = d; 
