@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -49,7 +49,6 @@ private:
 	bool m_edited;    // edited via editor
 	
 	std::string m_path; // E.g. /path/to/my/sample.wav
-	std::string m_name; // Sample name (can be changed)
 
 public:
 
@@ -60,17 +59,21 @@ public:
 
 	void setRate(int v);
 	void setChannels(int v);
-	void setPath(const std::string& p);
-	void setName(const std::string& p);
 	void setData(float* data, int size);
 	void setLogical(bool l);
 	void setEdited(bool e);
 
+	/* setPath
+	Sets new path 'p'. If 'id' != -1 inserts a numeric id next to the file 
+	extension, e.g. : /path/to/sample-[id].wav */
+	 
+	void setPath(const std::string& p, int id=-1);
+
 	std::string getBasename(bool ext=false) const;
+	std::string getExtension() const;
 	int getRate() const;
 	int getChannels() const;
 	std::string getPath() const;	
-	std::string getName() const;
 	int getBits() const;
 	float* getData() const;
 	int getSize() const;        // with channels count
