@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -302,12 +302,28 @@ void smooth(Wave* w, int a, int b)
 /* -------------------------------------------------------------------------- */
 
 
+void shift(Wave* w, int offset)
+{
+	if (offset < 0)
+		offset = (w->getSize() + w->getChannels()) + offset;
+
+	float* begin = w->getData();
+	float* end   = w->getData() + (w->getSize() * w->getChannels());
+
+	std::rotate(begin, end - (offset * w->getChannels()), end);
+	w->setEdited(true);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
 void reverse(Wave* w, int a, int b)
 {
 	/* https://stackoverflow.com/questions/33201528/reversing-an-array-of-structures-in-c */
 
-	float* begin = (w->getData() + (a * w->getChannels()));
-	float* end   = (w->getData() + (b * w->getChannels()));
+	float* begin = w->getData() + (a * w->getChannels());
+	float* end   = w->getData() + (b * w->getChannels());
 
 	std::reverse(begin, end);
 
