@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -113,9 +113,9 @@ int glue_loadChannel(SampleChannel* ch, const string& fname)
 
 Channel* glue_addChannel(int column, int type, int size)
 {
-	Channel* ch     = mh::addChannel(type);
-	geChannel* gch  = G_MainWin->keyboard->addChannel(column, ch, size);
-	ch->guiChannel  = gch;
+	Channel* ch    = mh::addChannel(type);
+	geChannel* gch = G_MainWin->keyboard->addChannel(column, ch, size);
+	ch->guiChannel = gch;
 	return ch;
 }
 
@@ -143,7 +143,7 @@ void glue_deleteChannel(Channel* ch)
 /* -------------------------------------------------------------------------- */
 
 
-void glue_freeChannel(Channel *ch)
+void glue_freeChannel(Channel* ch)
 {
 	if (ch->status == STATUS_PLAY) {
 		if (!gdConfirmWin("Warning", "This action will stop the channel: are you sure?"))
@@ -170,20 +170,20 @@ void glue_freeChannel(Channel *ch)
 /* -------------------------------------------------------------------------- */
 
 
-void glue_toggleArm(Channel *ch, bool gui)
+void glue_toggleArm(Channel* ch, bool gui)
 {
-	ch->armed = !ch->armed;
+	ch->setArmed(!ch->isArmed());
 	if (!gui)
-		ch->guiChannel->arm->value(ch->armed);
+		ch->guiChannel->arm->value(ch->isArmed());
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void glue_toggleInputMonitor(Channel *ch)
+void glue_toggleInputMonitor(Channel* ch)
 {
-	SampleChannel *sch = static_cast<SampleChannel*>(ch);
+	SampleChannel* sch = static_cast<SampleChannel*>(ch);
 	sch->inputMonitor = !sch->inputMonitor;
 }
 
@@ -191,10 +191,10 @@ void glue_toggleInputMonitor(Channel *ch)
 /* -------------------------------------------------------------------------- */
 
 
-int glue_cloneChannel(Channel *src)
+int glue_cloneChannel(Channel* src)
 {
-	Channel *ch    = mh::addChannel(src->type);
-	geChannel *gch = G_MainWin->keyboard->addChannel(src->guiChannel->getColumnIndex(), 
+	Channel* ch    = mh::addChannel(src->type);
+	geChannel* gch = G_MainWin->keyboard->addChannel(src->guiChannel->getColumnIndex(), 
 		ch, src->guiChannel->getSize());
 
 	ch->guiChannel = gch;
@@ -208,7 +208,7 @@ int glue_cloneChannel(Channel *src)
 /* -------------------------------------------------------------------------- */
 
 
-void glue_setVolume(Channel *ch, float v, bool gui, bool editor)
+void glue_setVolume(Channel* ch, float v, bool gui, bool editor)
 {
 	ch->volume = v;
 
@@ -264,7 +264,7 @@ void glue_setPanning(SampleChannel* ch, float val)
 /* -------------------------------------------------------------------------- */
 
 
-void glue_setMute(Channel *ch, bool gui)
+void glue_toggleMute(Channel* ch, bool gui)
 {
 	if (recorder::active && recorder::canRec(ch, clock::isRunning(), mixer::recording)) {
 		if (!ch->mute) {
@@ -290,7 +290,25 @@ void glue_setMute(Channel *ch, bool gui)
 /* -------------------------------------------------------------------------- */
 
 
-void glue_setSoloOn(Channel *ch, bool gui)
+void glue_toggleSolo(Channel* ch, bool gui)
+{
+	ch->solo ? glue_setSoloOn(ch, gui) : glue_setSoloOff(ch, gui);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void glue_kill(Channel* ch)
+{
+	ch->kill(0); // on frame 0: it's a user-generated event
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void glue_setSoloOn(Channel* ch, bool gui)
 {
 	/* if there's no solo session, store mute configuration of all chans
 	 * and start the session */
@@ -336,7 +354,7 @@ void glue_setSoloOn(Channel *ch, bool gui)
 /* -------------------------------------------------------------------------- */
 
 
-void glue_setSoloOff(Channel *ch, bool gui)
+void glue_setSoloOff(Channel* ch, bool gui)
 {
 	/* if this is uniqueSolo, stop solo session and restore mute status,
 	 * else mute this */
@@ -381,7 +399,7 @@ void glue_setSoloOff(Channel *ch, bool gui)
 /* -------------------------------------------------------------------------- */
 
 
-void glue_setBoost(SampleChannel *ch, float val)
+void glue_setBoost(SampleChannel* ch, float val)
 {
 	ch->setBoost(val);
 	gdSampleEditor *gdEditor = static_cast<gdSampleEditor*>(gu_getSubwindow(G_MainWin, WID_SAMPLE_EDITOR));
@@ -396,7 +414,17 @@ void glue_setBoost(SampleChannel *ch, float val)
 /* -------------------------------------------------------------------------- */
 
 
-void glue_startStopReadingRecs(SampleChannel *ch, bool gui)
+void glue_setName(Channel* ch, const string& name)
+{
+	ch->setName(name);
+	ch->guiChannel->update();
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void glue_toggleReadingRecs(SampleChannel* ch, bool gui)
 {
 	/* When you call glue_startReadingRecs with conf::treatRecsAsLoops, the
 	member value ch->readActions actually is not set to true immediately, because
@@ -416,7 +444,7 @@ void glue_startStopReadingRecs(SampleChannel *ch, bool gui)
 /* -------------------------------------------------------------------------- */
 
 
-void glue_startReadingRecs(SampleChannel *ch, bool gui)
+void glue_startReadingRecs(SampleChannel* ch, bool gui)
 {
 	if (conf::treatRecsAsLoops)
 		ch->recStatus = REC_WAITING;
@@ -433,7 +461,7 @@ void glue_startReadingRecs(SampleChannel *ch, bool gui)
 /* -------------------------------------------------------------------------- */
 
 
-void glue_stopReadingRecs(SampleChannel *ch, bool gui)
+void glue_stopReadingRecs(SampleChannel* ch, bool gui)
 {
 	/* First of all, if the mixer is not running just stop and disable everything.
 	Then if "treatRecsAsLoop" wait until the sequencer reaches beat 0, so put the
