@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -81,7 +81,7 @@ void glue_keyRelease(Channel *ch, bool ctrl, bool shift)
 void glue_keyPress(MidiChannel *ch, bool ctrl, bool shift)
 {
 	if (ctrl)
-		glue_setMute(ch);
+		glue_toggleMute(ch);
 	else
 	if (shift)
 		ch->kill(0);        // on frame 0: user-generated event
@@ -98,7 +98,7 @@ void glue_keyPress(SampleChannel *ch, bool ctrl, bool shift)
 	/* case CTRL */
 
 	if (ctrl)
-		glue_setMute(ch);
+		glue_toggleMute(ch);
 
 	/* case SHIFT
 	 *
@@ -316,12 +316,12 @@ int glue_stopInputRec(bool gui)
   they must start playing right away at the current frame, not at the next first
   beat. */
 
-	for (unsigned i=0; i<mixer::channels.size(); i++) {
-		if (mixer::channels.at(i)->type == CHANNEL_MIDI)
+	for (Channel* ch : mixer::channels) {
+		if (ch->type == CHANNEL_MIDI)
 			continue;
-		SampleChannel *ch = (SampleChannel*) mixer::channels.at(i);
-		if (ch->mode & (LOOP_ANY) && ch->status == STATUS_OFF && ch->armed)
-			ch->start(clock::getCurrentFrame(), true, clock::getQuantize(),
+		SampleChannel* sch = static_cast<SampleChannel*>(ch);
+		if (sch->mode & (LOOP_ANY) && sch->status == STATUS_OFF && sch->isArmed())
+			sch->start(clock::getCurrentFrame(), true, clock::getQuantize(),
         clock::isRunning(), true, true);
 	}
 
