@@ -7,7 +7,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -34,11 +34,28 @@
 
 #ifdef WITH_VST
 
-class Plugin *glue_addPlugin(class Channel *ch, int index, int stackType);
 
-void glue_swapPlugins(class Channel *ch, int indexP1, int indexP2, int stackType);
+class Plugin;
+class Channel;
+
+
+namespace giada {
+namespace c     {
+namespace plugin 
+{
+Plugin* addPlugin(Channel* ch, int index, int stackType);
+void swapPlugins(Channel* ch, int indexP1, int indexP2, int stackType);
+void freePlugin(Channel* ch, int index, int stackType);
+void setParameter(Plugin* p, int index, float value, bool gui=true); 
+void setProgram(Plugin* p, int index);
+
+/* setPluginPathCb
+Callback attached to the DirBrowser for adding new Plug-in search paths in the
+configuration window. */
+
+void setPluginPathCb(void* data);
+}}}; // giada::c::plugin::
 
-void glue_freePlugin(class Channel *ch, int index, int stackType);
 
 #endif
 
