@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -29,13 +29,35 @@
 #define G_GLUE_RECORDER_H
 
 
+#include <vector>
+#include "../core/recorder.h"
+
+
 class geChannel;
 
 
-void glue_clearAllActions(geChannel *gch);
-void glue_clearMuteActions(geChannel *gch);
-void glue_clearVolumeActions(geChannel *gch);
-void glue_clearStartStopActions(geChannel *gch);
+namespace giada {
+namespace c     {
+namespace recorder 
+{
+void clearAllActions(geChannel *gch);
+void clearMuteActions(geChannel *gch);
+void clearVolumeActions(geChannel *gch);
+void clearStartStopActions(geChannel *gch);
 
+/* recordMidiAction
+Records a new MIDI action at frame_a. If frame_b == 0, uses the default action
+size. This function is designed for the Piano Roll (not for live recording). */
+
+void recordMidiAction(int chan, int note, int frame_a, int frame_b=0);
+
+/* getMidiActions
+Returns a list of Composite actions, ready to be displayed in a MIDI note
+editor as pairs of NoteOn+NoteOff. */
+
+std::vector<giada::m::recorder::Composite> getMidiActions(int channel, 
+	int frameLimit);
+
+}}} // giada::c::recorder::
 
 #endif
