@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -37,6 +37,7 @@
 #include "../gui/elems/sampleEditor/panTool.h"
 #include "../gui/elems/sampleEditor/pitchTool.h"
 #include "../gui/elems/sampleEditor/rangeTool.h"
+#include "../gui/elems/sampleEditor/shiftTool.h"
 #include "../gui/elems/sampleEditor/waveform.h"
 #include "../gui/elems/mainWindow/keyboard/channel.h"
 #include "../core/sampleChannel.h"
@@ -103,6 +104,7 @@ void setBeginEnd(SampleChannel* ch, int b, int e)
 
 void cut(SampleChannel* ch, int a, int b)
 {
+	copy(ch, a, b);
 	if (!wfx::cut(ch->wave, a, b)) {
 		gdAlert("Unable to cut the sample!");
 		return;
@@ -136,8 +138,10 @@ void copy(SampleChannel* ch, int a, int b)
 
 void paste(SampleChannel* ch, int a)
 {
-	if (!isWaveBufferFull())
+	if (!isWaveBufferFull()) {
+		gu_log("[sampleEditor::paste] Buffer is empty, nothing to paste\n");
 		return;
+	}
 	
 	wfx::paste(m_waveBuffer, ch->wave, a);
 
@@ -278,8 +282,7 @@ void toNewChannel(SampleChannel* ch, int a, int b)
 		return;
 	}
 
-	newCh->pushWave(wave, true);
-
+	newCh->pushWave(wave);
 	newCh->guiChannel->update();
 }
 
@@ -292,4 +295,18 @@ bool isWaveBufferFull()
 	return m_waveBuffer != nullptr;
 }
 
+
+/* -------------------------------------------------------------------------- */
+
+
+void shift(SampleChannel* ch, int offset)
+{
+	wfx::shift(ch->wave, offset - ch->getShift());
+	ch->setShift(offset);
+	gdSampleEditor* gdEditor = getSampleEditorWindow();
+	gdEditor->shiftTool->refresh();
+	gdEditor->waveTools->waveform->refresh();	
+}
+
+
 }}}; // giada::c::sampleEditor::
