@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -34,10 +34,12 @@
 #include "../core/patch.h"
 #include "../core/sampleChannel.h"
 #include "../core/midiChannel.h"
+#include "../core/waveManager.h"
 #include "../core/clock.h"
 #include "../core/wave.h"
 #include "../utils/gui.h"
 #include "../utils/log.h"
+#include "../utils/string.h"
 #include "../utils/fs.h"
 #include "../gui/elems/basics/progress.h"
 #include "../gui/elems/mainWindow/keyboard/column.h"
@@ -61,7 +63,7 @@ using namespace giada::m;
 
 #ifdef WITH_VST
 
-static void __glue_fillPatchGlobalsPlugins__(vector <Plugin *> *host, vector<patch::plugin_t> *patch)
+static void glue_fillPatchGlobalsPlugins__(vector <Plugin *> *host, vector<patch::plugin_t> *patch)
 {
 	for (unsigned i=0; i<host->size(); i++) {
 		Plugin *pl = host->at(i);
@@ -81,7 +83,7 @@ static void __glue_fillPatchGlobalsPlugins__(vector <Plugin *> *host, vector<pat
 /* -------------------------------------------------------------------------- */
 
 
-static void __glue_fillPatchColumns__()
+static void glue_fillPatchColumns__()
 {
 	for (unsigned i=0; i<G_MainWin->keyboard->getTotalColumns(); i++) {
 		geColumn *gCol = G_MainWin->keyboard->getColumn(i);
@@ -106,7 +108,7 @@ static void __glue_fillPatchColumns__()
 /* -------------------------------------------------------------------------- */
 
 
-static void __glue_fillPatchChannels__(bool isProject)
+static void glue_fillPatchChannels__(bool isProject)
 {
 	for (unsigned i=0; i<mixer::channels.size(); i++) {
 		mixer::channels.at(i)->writePatch(i, isProject);
@@ -117,7 +119,7 @@ static void __glue_fillPatchChannels__(bool isProject)
 /* -------------------------------------------------------------------------- */
 
 
-static void __glue_fillPatchGlobals__(const string &name)
+static void glue_fillPatchGlobals__(const string &name)
 {
 	patch::version      = G_VERSION_STR;
 	patch::versionMajor = G_VERSION_MAJOR;
@@ -134,9 +136,9 @@ static void __glue_fillPatchGlobals__(const string &name)
 
 #ifdef WITH_VST
 
-	__glue_fillPatchGlobalsPlugins__(pluginHost::getStack(pluginHost::MASTER_IN),
+	glue_fillPatchGlobalsPlugins__(pluginHost::getStack(pluginHost::MASTER_IN),
 			&patch::masterInPlugins);
-	__glue_fillPatchGlobalsPlugins__(pluginHost::getStack(pluginHost::MASTER_OUT),
+	glue_fillPatchGlobalsPlugins__(pluginHost::getStack(pluginHost::MASTER_OUT),
 			&patch::masterOutPlugins);
 
 #endif
@@ -146,14 +148,14 @@ static void __glue_fillPatchGlobals__(const string &name)
 /* -------------------------------------------------------------------------- */
 
 
-static bool __glue_savePatch__(const string &fullPath, const string &name,
+static bool glue_savePatch__(const string &fullPath, const string &name,
 		bool isProject)
 {
 	patch::init();
 
-	__glue_fillPatchGlobals__(name);
-	__glue_fillPatchChannels__(isProject);
-	__glue_fillPatchColumns__();
+	glue_fillPatchGlobals__(name);
+	glue_fillPatchChannels__(isProject);
+	glue_fillPatchColumns__();
 
 	if (patch::write(fullPath)) {
 		gu_updateMainWinLabel(name);
@@ -167,11 +169,34 @@ static bool __glue_savePatch__(const string &fullPath, const string &name,
 /* -------------------------------------------------------------------------- */
 
 
-void glue_savePatch(void *data)
+static string glue_makeSamplePath__(const string& base, const Wave* w, int k)
 {
-	gdBrowserSave *browser = (gdBrowserSave*) data;
-	string name            = browser->getName();
-	string fullPath        = browser->getCurrentPath() + G_SLASH + gu_stripExt(name) + ".gptc";
+	return base + G_SLASH + w->getBasename(false) + "-" + gu_iToString(k) + "." +  w->getExtension();
+} 
+
+
+static string glue_makeUniqueSamplePath__(const string& base, const SampleChannel* ch)
+{
+	string path = base + G_SLASH + ch->wave->getBasename(true);
+	if (mh::uniqueSamplePath(ch, path))
+		return path;
+
+	int k = 0;
+	path = glue_makeSamplePath__(base, ch->wave, k);
+	while (!mh::uniqueSamplePath(ch, path))
+		path = glue_makeSamplePath__(base, ch->wave, k++);
+	return path;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void glue_savePatch(void* data)
+{
+	gdBrowserSave* browser = (gdBrowserSave*) data;
+	string name            = gu_stripExt(browser->getName());
+	string fullPath        = browser->getCurrentPath() + G_SLASH + name + ".gptc";
 
 	if (name == "") {
 		gdAlert("Please choose a file name.");
@@ -182,7 +207,7 @@ void glue_savePatch(void *data)
 		if (!gdConfirmWin("Warning", "File exists: overwrite?"))
 			return;
 
-	if (__glue_savePatch__(fullPath, name, false)) {  // false == not a project
+	if (glue_savePatch__(fullPath, name, false)) {  // false == not a project
 		conf::patchPath = gu_dirname(fullPath);
 		browser->do_callback();
 	}
@@ -222,58 +247,57 @@ void glue_loadPatch(void* data)
 		return;
 	}
 
-	/* close all other windows. This prevents segfault if plugin
-	 * windows GUIs are on. */
+	/* Close all other windows. This prevents segfault if plugin windows GUIs are 
+	open. */
 
 	gu_closeAllSubwindows();
 
-	/* reset the system. False(1): don't update the gui right now. False(2): do
-	 * not create empty columns. */
+	/* Reset the system. False(1): don't update the gui right now. False(2): do 
+	not create empty columns. */
 
 	glue_resetToInitState(false, false);
 
 	browser->setStatusBar(0.1f);
-	//__glue_setProgressBar__(status, 0.1f);
 
-	/* Add common stuff, columns and channels. Also increment the progress bar
-	 * by 0.8 / total_channels steps.  */
+	/* Add common stuff, columns and channels. Also increment the progress bar by 
+	0.8 / total_channels steps.  */
 
 	float steps = 0.8 / patch::channels.size();
 	
 	for (const patch::column_t& col : patch::columns) {
 		G_MainWin->keyboard->addColumn(col.width);
-		for (unsigned k=0; k<patch::channels.size(); k++) {
-			if (patch::channels.at(k).column == col.index) {
-				Channel* ch = glue_addChannel(patch::channels.at(k).column,
-					patch::channels.at(k).type, patch::channels.at(k).size);
+		unsigned k = 0;
+		for (const patch::channel_t& pch : patch::channels) {
+			if (pch.column == col.index) {
+				Channel* ch = glue_addChannel(pch.column, pch.type, pch.size);
 				ch->readPatch(basePath, k, &mixer::mutex_plugins, conf::samplerate,
 					conf::rsmpQuality);
 			}
 			browser->setStatusBar(steps);
+			k++;
 		}
 	}
 
-	/* fill Mixer */
+	/* Fill Mixer. */
 
 	mh::readPatch();
 
-	/* let recorder recompute the actions' positions if the current
-	 * samplerate != patch samplerate */
+	/* Let recorder recompute the actions' positions if the current 
+	samplerate != patch samplerate. */
 
 	recorder::updateSamplerate(conf::samplerate, patch::samplerate);
 
-	/* save patchPath by taking the last dir of the broswer, in order to
-	 * reuse it the next time */
+	/* Save patchPath by taking the last dir of the broswer, in order to reuse it 
+	the next time. */
 
 	conf::patchPath = gu_dirname(fullPath);
 
-	/* refresh GUI */
+	/* Refresh GUI. */
 
 	gu_updateControls();
 	gu_updateMainWinLabel(patch::name);
 
 	browser->setStatusBar(0.1f);
-	//__glue_setProgressBar__(status, 1.0f);
 
 	gu_log("[glue] patch loaded successfully\n");
 
@@ -291,12 +315,12 @@ void glue_loadPatch(void* data)
 /* -------------------------------------------------------------------------- */
 
 
-void glue_saveProject(void *data)
+void glue_saveProject(void* data)
 {
-	gdBrowserSave *browser = (gdBrowserSave*) data;
-	string name            = browser->getName();
-	string folderPath      = browser->getCurrentPath(); //browser->getSelectedItem();
-	string fullPath        = folderPath + G_SLASH + gu_stripExt(name) + ".gprj";
+	gdBrowserSave* browser = (gdBrowserSave*) data;
+	string name            = gu_stripExt(browser->getName());
+	string folderPath      = browser->getCurrentPath();
+	string fullPath        = folderPath + G_SLASH + name + ".gprj";
 
 	if (name == "") {
 		gdAlert("Please choose a project name.");
@@ -307,38 +331,36 @@ void glue_saveProject(void *data)
 		return;
 
 	if (!gu_dirExists(fullPath) && !gu_mkdir(fullPath)) {
-		gu_log("[glue_saveProject] unable to make project directory!\n");
+		gu_log("[glue_saveProject] Unable to make project directory!\n");
 		return;
 	}
 
-	gu_log("[glue_saveProject] project dir created: %s\n", fullPath.c_str());
+	gu_log("[glue_saveProject] Project dir created: %s\n", fullPath.c_str());
 
-	/* copy all samples inside the folder. Takes and logical ones are saved
-	 * via glue_saveSample() */
+	/* Copy all samples inside the folder. Takes and logical ones are saved via 
+	glue_saveSample(). Update the new sample path: everything now comes from the 
+	project folder (folderPath). Also make sure the file path is unique inside the 
+	project folder.*/
 
-	for (unsigned i=0; i<mixer::channels.size(); i++) {
+	for (const Channel* ch : mixer::channels) {
 
-		if (mixer::channels.at(i)->type == CHANNEL_MIDI)
+		if (ch->type == CHANNEL_MIDI)
 			continue;
 
-		SampleChannel *ch = (SampleChannel*) mixer::channels.at(i);
+		const SampleChannel* sch = static_cast<const SampleChannel*>(ch);
 
-		if (ch->wave == nullptr)
+		if (sch->wave == nullptr)
 			continue;
 
-		/* update the new samplePath: everything now comes from the project
-		 * folder (folderPath). Also remove any existing file. */
+		sch->wave->setPath(glue_makeUniqueSamplePath__(fullPath, sch));
 
-		string samplePath = fullPath + G_SLASH + ch->wave->getBasename(true);
+		gu_log("[glue_saveProject] Save file to %s\n", sch->wave->getPath().c_str());
 
-		if (gu_fileExists(samplePath))
-			remove(samplePath.c_str());
-		if (ch->save(samplePath.c_str()))
-			ch->wave->setPath(samplePath);
+		waveManager::save(sch->wave, sch->wave->getPath()); // TODO - error checking	
 	}
 
-	string gptcPath = fullPath + G_SLASH + gu_stripExt(name) + ".gptc";
-	if (__glue_savePatch__(gptcPath, name, true)) // true == it's a project
+	string gptcPath = fullPath + G_SLASH + name + ".gptc";
+	if (glue_savePatch__(gptcPath, name, true)) // true == it's a project
 		browser->do_callback();
 	else
 		gdAlert("Unable to save the project!");
@@ -374,7 +396,7 @@ void glue_loadSample(void* data)
 
 void glue_saveSample(void *data)
 {
-	gdBrowserSave *browser = (gdBrowserSave*) data;
+	gdBrowserSave* browser = (gdBrowserSave*) data;
 	string name            = browser->getName();
 	string folderPath      = browser->getCurrentPath();
 
@@ -391,7 +413,9 @@ void glue_saveSample(void *data)
 		if (!gdConfirmWin("Warning", "File exists: overwrite?"))
 			return;
 
-	if (static_cast<SampleChannel*>(browser->getChannel())->save(filePath.c_str())) {
+	SampleChannel* ch = static_cast<SampleChannel*>(browser->getChannel());
+
+	if (waveManager::save(ch->wave, filePath)) {
 		gu_log("[glue_saveSample] sample saved to %s\n", filePath.c_str());
 		conf::samplePath = gu_dirname(filePath);
 		browser->do_callback();
