@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -42,15 +42,15 @@ using std::string;
 using namespace giada::m;
 
 
-gdBrowserBase::gdBrowserBase(int x, int y, int w, int h, const string &title,
-		const string &path, void (*callback)(void*))
+gdBrowserBase::gdBrowserBase(int x, int y, int w, int h, const string& title,
+		const string& path, void (*callback)(void*))
 	:	gdWindow(x, y, w, h, title.c_str()), callback(callback)
 {
 	set_non_modal();
 
 	groupTop = new Fl_Group(8, 8, w-16, 40);
     hiddenFiles = new geCheck(groupTop->x(), groupTop->y(), 400, 20, "Show hidden files");
-		where = new geInput(groupTop->x(), hiddenFiles->y()+hiddenFiles->h(), 152, 20);
+		where = new geInput(groupTop->x(), hiddenFiles->y()+hiddenFiles->h(), 20, 20);
 		updir	= new geButton(groupTop->x()+groupTop->w()-20, where->y(), 20, 20, "", updirOff_xpm, updirOn_xpm);
 	groupTop->end();
 	groupTop->resizable(where);
@@ -108,18 +108,31 @@ gdBrowserBase::~gdBrowserBase()
 /* -------------------------------------------------------------------------- */
 
 
-void gdBrowserBase::cb_up   (Fl_Widget *v, void *p) { ((gdBrowserBase*)p)->__cb_up(); }
-void gdBrowserBase::cb_close(Fl_Widget *v, void *p) { ((gdBrowserBase*)p)->__cb_close(); }
-void gdBrowserBase::cb_toggleHiddenFiles(Fl_Widget *v, void *p) { ((gdBrowserBase*)p)->__cb_toggleHiddenFiles(); }
+void gdBrowserBase::cb_up   (Fl_Widget* v, void* p) { ((gdBrowserBase*)p)->cb_up(); }
+void gdBrowserBase::cb_close(Fl_Widget* v, void* p) { ((gdBrowserBase*)p)->cb_close(); }
+void gdBrowserBase::cb_toggleHiddenFiles(Fl_Widget *v, void *p) { ((gdBrowserBase*)p)->cb_toggleHiddenFiles(); }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void gdBrowserBase::__cb_up()
+void gdBrowserBase::cb_up()
 {
 	string dir = browser->getCurrentDir();
-	dir = dir.substr(0, dir.find_last_of(G_SLASH_STR));  // remove up to the next slash
+
+	/* Take 'dir' path and remove all chars up to the next slash, e.g.:
+		/path/to/my/dir -> /path/to/my
+	Make sure not to remove the leading '/' (OS X/Linux only). */
+
+	dir = dir.substr(0, dir.find_last_of(G_SLASH_STR));
+
+#if defined(G_OS_MAC) || defined(G_OS_LINUX)
+
+	if (dir.empty())
+		dir = G_SLASH_STR;
+
+#endif
+
 	browser->loadDir(dir);
 	where->value(browser->getCurrentDir().c_str());
 }
@@ -128,7 +141,7 @@ void gdBrowserBase::__cb_up()
 /* -------------------------------------------------------------------------- */
 
 
-void gdBrowserBase::__cb_close()
+void gdBrowserBase::cb_close()
 {
 	do_callback();
 }
@@ -137,7 +150,7 @@ void gdBrowserBase::__cb_close()
 /* -------------------------------------------------------------------------- */
 
 
-void gdBrowserBase::__cb_toggleHiddenFiles()
+void gdBrowserBase::cb_toggleHiddenFiles()
 {
 	browser->toggleHiddenFiles();
 }
@@ -174,16 +187,28 @@ void gdBrowserBase::hideStatusBar()
 /* -------------------------------------------------------------------------- */
 
 
-string gdBrowserBase::getCurrentPath()
+string gdBrowserBase::getCurrentPath() const 
+{ 
+	return where->value(); 
+}
+
+
+Channel* gdBrowserBase::getChannel() const 
+{ 
+	return channel; 
+}
+
+
+string gdBrowserBase::getSelectedItem() const 
 {
-  return where->value();
+	return browser->getSelectedItem();
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-string gdBrowserBase::getSelectedItem()
-{
-	return browser->getSelectedItem();
+void gdBrowserBase::fireCallback() const
+{ 
+	callback((void*) this); 
 }
