@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -34,34 +34,39 @@
 #include "midiInputBase.h"
 
 
+class Channel;
+class geScroll;
+class geCheck;
+class geChoice;
+
+
 class gdMidiInputChannel : public gdMidiInputBase
 {
 private:
 
-  static const int LEARNER_WIDTH = 284;
+	Channel* ch;
 
-	class Channel *ch;
+	geScroll* container;
+	geCheck*  enable;
+	geChoice* channel;
 
-  class geScroll *container;
-	class geCheck   *enable;
+	static void cb_enable(Fl_Widget* w, void* p);
+	static void cb_setChannel(Fl_Widget* w, void* p);
+	void cb_enable();
+	void cb_setChannel();
 
-	//gVector <geMidiLearner *> items; // plugins parameters
-
-	static void cb_enable  (Fl_Widget *w, void *p);
-	inline void __cb_enable();
-
-  void addChannelLearners();
+	void addChannelLearners();
 
 #ifdef WITH_VST
 
-  void addPluginLearners();
+	void addPluginLearners();
 
 #endif
 
 public:
 
-	gdMidiInputChannel(class Channel *ch);
-  ~gdMidiInputChannel();
+	gdMidiInputChannel(Channel* ch);
+	~gdMidiInputChannel();
 };
 
 
