@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -41,38 +41,17 @@
 using namespace giada::m;
 
 
-gePianoItem::gePianoItem(int X, int Y, int rel_x, int rel_y, recorder::action *_a,
-  recorder::action *_b, gdActionEditor *pParent)
+gePianoItem::gePianoItem(int X, int Y, int rel_x, int rel_y, recorder::action a,
+	recorder::action b, gdActionEditor* pParent)
 	: geBasePianoItem(X, Y, MIN_WIDTH, pParent),
-	  a              (_a),
-	  b              (_b),
-		event_a        (0x00),
-		event_b        (0x00),
+		a              (a),
+		b              (b),
 		changed        (false)
 {
-	/* a is a pointer: action exists, needs to be displayed */
-
-	if (a) {
-		note    = kernelMidi::getB2(a->iValue);
-		frame_a = a->frame;
-		frame_b = b->frame;
-		event_a = a->iValue;
-		event_b = b->iValue;
-		int newX = rel_x + (frame_a / pParent->zoom);
-		int newY = rel_y + getY(note);
-		int newW = (frame_b - frame_a) / pParent->zoom;
-		resize(newX, newY, newW, h());
-	}
-
-	/* a is null: action needs to be recorded from scratch */
-
-	else {
-		note    = getNote(rel_y);
-		frame_a = rel_x * pParent->zoom;
-		frame_b = (rel_x + 20) * pParent->zoom;
-		record();
-		size((frame_b - frame_a) / pParent->zoom, h());
-	}
+	int newX = rel_x + (a.frame / pParent->zoom);
+	int newY = rel_y + getY(kernelMidi::getB2(a.iValue));
+	int newW = (b.frame - a.frame) / pParent->zoom;
+	resize(newX, newY, newW, h());
 }
 
 
@@ -81,12 +60,12 @@ gePianoItem::gePianoItem(int X, int Y, int rel_x, int rel_y, recorder::action *_
 
 void gePianoItem::reposition(int pianoRollX)
 {
-  int newX = pianoRollX + (frame_a / pParent->zoom);
-  int newW = ((frame_b - frame_a) / pParent->zoom);
-  if (newW < MIN_WIDTH)
-    newW = MIN_WIDTH;
-  resize(newX, y(), newW, h());
-  redraw();
+	int newX = pianoRollX + (a.frame / pParent->zoom);
+	int newW = ((b.frame - a.frame) / pParent->zoom);
+	if (newW < MIN_WIDTH)
+		newW = MIN_WIDTH;
+	resize(newX, y(), newW, h());
+	redraw();
 }
 
 
@@ -100,11 +79,11 @@ bool gePianoItem::overlap()
 	 * end   = the lowest value between the two ending points
 	 * if start < end then there's an overlap of end-start pixels. */
 
-	geNoteEditor *pPiano = static_cast<geNoteEditor*>(parent());
+	geNoteEditor* noteEditor = static_cast<geNoteEditor*>(parent());
 
-	for (int i=0; i<pPiano->children(); i++) {
+	for (int i=0; i<noteEditor->children(); i++) {
 
-		gePianoItem *pItem = static_cast<gePianoItem*>(pPiano->child(i));
+		gePianoItem* pItem = static_cast<gePianoItem*>(noteEditor->child(i));
 
 		/* don't check against itself and with different y positions */
 
@@ -134,49 +113,19 @@ void gePianoItem::draw()
 /* -------------------------------------------------------------------------- */
 
 
-void gePianoItem::record()
+void gePianoItem::removeAction()
 {
-	/* avoid frame overflow */
-
-	int overflow = frame_b - clock::getTotalFrames();
-	if (overflow > 0) {
-		frame_b -= overflow;
-		frame_a -= overflow;
-	}
-
-	event_a |= (MIDI_NOTE_ON);
-	event_a |= (note << 16);   // note value
-	event_a |= (MIDI_VELOCITY);
-	event_a |= (0x00);
-
-	event_b |= (MIDI_NOTE_OFF);
-	event_b |= (note << 16);   // note value
-	event_b |= (MIDI_VELOCITY);
-	event_b |= (0x00);
-
-	recorder::rec(pParent->chan->index, G_ACTION_MIDI, frame_a, event_a);
-	recorder::rec(pParent->chan->index, G_ACTION_MIDI, frame_b, event_b);
-  pParent->chan->hasActions = true;
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void gePianoItem::remove()
-{
-  MidiChannel *ch = static_cast<MidiChannel*>(pParent->chan);
-	recorder::deleteAction(ch->index, frame_a, G_ACTION_MIDI, true,
-    &mixer::mutex_recs, event_a, 0.0);
-	recorder::deleteAction(ch->index, frame_b, G_ACTION_MIDI, true,
-    &mixer::mutex_recs, event_b, 0.0);
+	MidiChannel* ch = static_cast<MidiChannel*>(pParent->chan);
+	recorder::deleteAction(ch->index, a.frame, G_ACTION_MIDI, true,
+		&mixer::mutex_recs, a.iValue, 0.0);
+	recorder::deleteAction(ch->index, b.frame, G_ACTION_MIDI, true,
+		&mixer::mutex_recs, b.iValue, 0.0);
 
 	/* Send a note-off in case we are deleting it in a middle of a key_on/key_off
-  sequence. */
+	sequence. */
 
-	ch->sendMidi(event_b);
-  ch->hasActions = recorder::hasActions(ch->index);
-  static_cast<gePianoRoll*>(parent())->cursorOnItem = false;
+	ch->sendMidi(b.iValue);
+	ch->hasActions = recorder::hasActions(ch->index);
 }
 
 
@@ -190,7 +139,6 @@ int gePianoItem::handle(int e)
 	switch (e) {
 
 		case FL_ENTER: {
-      static_cast<gePianoRoll*>(parent())->cursorOnItem = true;
 			selected = true;
 			ret = 1;
 			redraw();
@@ -199,7 +147,6 @@ int gePianoItem::handle(int e)
 
 		case FL_LEAVE: {
 			fl_cursor(FL_CURSOR_DEFAULT, FL_WHITE, FL_BLACK);
-      static_cast<gePianoRoll*>(parent())->cursorOnItem = false;
 			selected = false;
 			ret = 1;
 			redraw();
@@ -227,14 +174,13 @@ int gePianoItem::handle(int e)
 		}
 
 		case FL_PUSH: {
-
 			push_x = Fl::event_x() - x();
 			old_x  = x();
 			old_w  = w();
 
 			if (Fl::event_button3()) {
 				fl_cursor(FL_CURSOR_DEFAULT, FL_WHITE, FL_BLACK);
-				remove();
+				removeAction();
 				hide();   // for Windows
 				Fl::delete_widget(this);
 				static_cast<geNoteEditor*>(parent())->redraw();
@@ -302,8 +248,11 @@ int gePianoItem::handle(int e)
 
 		case FL_RELEASE: {
 
-			/* delete & record the action, only if it doesn't overlap with
-			 * another one */
+
+			gePianoRoll* pianoRoll = static_cast<gePianoRoll*>(parent());
+
+			/* Delete and record the action, only if it doesn't overlap with another 
+			existing one. */
 
 			if (overlap()) {
 				resize(old_x, y(), old_w, h());
@@ -311,15 +260,15 @@ int gePianoItem::handle(int e)
 			}
 			else
 			if (changed) {
-				remove();
-				note    = getNote(getRelY());
-				frame_a = getRelX() * pParent->zoom;
-				frame_b = (getRelX()+w()) * pParent->zoom;
-				record();
+				removeAction();
+				int note    = pianoRoll->yToNote(getRelY());
+				int frame_a = getRelX() * pParent->zoom;
+				int frame_b = (getRelX()+w()) * pParent->zoom;
+				pianoRoll->recordAction(note, frame_a, frame_b);
 				changed = false;
 			}
 
-			static_cast<geNoteEditor*>(parent())->redraw();
+			pianoRoll->redraw();
 
 			ret = 1;
 			break;
@@ -332,18 +281,9 @@ int gePianoItem::handle(int e)
 /* -------------------------------------------------------------------------- */
 
 
-int gePianoItem::getNote(int rel_y)
-{
-  return gePianoRoll::MAX_KEYS - (rel_y / gePianoRoll::CELL_H);
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
 int gePianoItem::getRelY()
 {
-  return y() - parent()->y();
+	return y() - parent()->y();
 }
 
 
@@ -352,5 +292,5 @@ int gePianoItem::getRelY()
 
 int gePianoItem::getRelX()
 {
-  return x() - parent()->x();
+	return x() - parent()->x();
 }
