@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -41,12 +41,12 @@ using namespace giada::m;
 
 
 gePianoItemOrphaned::gePianoItemOrphaned(int x, int y, int xRel, int yRel,
-  recorder::action *action, gdActionEditor *pParent)
+  recorder::action action, gdActionEditor* pParent)
   : geBasePianoItem(x, y, WIDTH, pParent)
 {
-  note  = kernelMidi::getB2(action->iValue);
-  frame = action->frame;
-  event = action->iValue;
+  note  = kernelMidi::getB2(action.iValue);
+  frame = action.frame;
+  event = action.iValue;
   int newX = xRel + (frame / pParent->zoom);
   int newY = yRel + getY(note);
   resize(newX, newY, w(), h());
