@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -49,7 +49,7 @@ public:
   static const int WIDTH = 12;
 
   gePianoItemOrphaned(int x, int y, int xRel, int yRel,
-    struct giada::m::recorder::action *action, gdActionEditor *pParent);
+    struct giada::m::recorder::action action, gdActionEditor* pParent);
 
   void draw() override;
   int handle(int e) override;
