@@ -20,7 +20,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -69,9 +69,9 @@ public:
 
 	int handle(int e) override;
 	void draw() override;
+	void resize(int x, int y, int w, int h) override;
 
 	int getMinSize() const;
-	void resize(int x, int y, int w, int h);
 };
 
 
