@@ -30,15 +30,16 @@
 #include "../../../../core/graphics.h"
 #include "../../../../core/midiChannel.h"
 #include "../../../../utils/gui.h"
+#include "../../../../utils/string.h"
 #include "../../../../glue/channel.h"
 #include "../../../../glue/io.h"
 #include "../../../../glue/recorder.h"
 #include "../../../dialogs/gd_mainWindow.h"
-#include "../../../dialogs/sampleEditor.h"
+#include "../../../dialogs/channelNameInput.h"
 #include "../../../dialogs/gd_actionEditor.h"
 #include "../../../dialogs/gd_warnings.h"
 #include "../../../dialogs/gd_keyGrabber.h"
-#include "../../../dialogs/gd_pluginList.h"
+#include "../../../dialogs/pluginList.h"
 #include "../../../dialogs/midiIO/midiInputChannel.h"
 #include "../../../dialogs/midiIO/midiOutputMidiCh.h"
 #include "../../basics/boxtypes.h"
@@ -46,13 +47,15 @@
 #include "../../basics/statusButton.h"
 #include "../../basics/dial.h"
 #include "column.h"
+#include "midiChannelButton.h"
 #include "midiChannel.h"
 
 
-extern gdMainWindow *G_MainWin;
+extern gdMainWindow* G_MainWin;
 
 
-using namespace giada::m;
+using std::string;
+using namespace giada;
 
 
 namespace
@@ -72,6 +75,7 @@ enum class Menu
 	RESIZE_H3,
 	RESIZE_H4,
 	__END_RESIZE_SUBMENU__,
+	RENAME_CHANNEL,
 	CLONE_CHANNEL,
 	DELETE_CHANNEL
 };
@@ -80,9 +84,9 @@ enum class Menu
 /* -------------------------------------------------------------------------- */
 
 
-void menuCallback(Fl_Widget *w, void *v)
+void menuCallback(Fl_Widget* w, void* v)
 {
-	geMidiChannel *gch = static_cast<geMidiChannel*>(w);
+	geMidiChannel* gch = static_cast<geMidiChannel*>(w);
 	Menu selectedItem = (Menu) (intptr_t) v;
 
 	switch (selectedItem)
@@ -96,7 +100,7 @@ void menuCallback(Fl_Widget *w, void *v)
 			gu_openSubWindow(G_MainWin, new gdActionEditor(gch->ch), WID_ACTION_EDITOR);
 			break;
 		case Menu::CLEAR_ACTIONS_ALL:
-			glue_clearAllActions(gch);
+			c::recorder::clearAllActions(gch);
 			break;
 		case Menu::SETUP_KEYBOARD_INPUT:
 			gu_openSubWindow(G_MainWin, new gdKeyGrabber(gch->ch), 0);
@@ -126,6 +130,9 @@ void menuCallback(Fl_Widget *w, void *v)
 			break;
 		case Menu::CLONE_CHANNEL:
 			glue_cloneChannel(gch->ch);
+			break;		
+		case Menu::RENAME_CHANNEL:
+			gu_openSubWindow(G_MainWin, new gdChannelNameInput(gch->ch), WID_SAMPLE_NAME);
 			break;
 		case Menu::DELETE_CHANNEL:
 			glue_deleteChannel(gch->ch);
@@ -139,7 +146,7 @@ void menuCallback(Fl_Widget *w, void *v)
 /* -------------------------------------------------------------------------- */
 
 
-geMidiChannel::geMidiChannel(int X, int Y, int W, int H, MidiChannel *ch)
+geMidiChannel::geMidiChannel(int X, int Y, int W, int H, MidiChannel* ch)
 	: geChannel(X, Y, W, H, CHANNEL_MIDI, ch)
 {
 	begin();
@@ -197,14 +204,14 @@ geMidiChannel::geMidiChannel(int X, int Y, int W, int H, MidiChannel *ch)
 /* -------------------------------------------------------------------------- */
 
 
-void geMidiChannel::cb_button      (Fl_Widget *v, void *p) { ((geMidiChannel*)p)->__cb_button(); }
-void geMidiChannel::cb_openMenu    (Fl_Widget *v, void *p) { ((geMidiChannel*)p)->__cb_openMenu(); }
+void geMidiChannel::cb_button  (Fl_Widget* v, void* p) { ((geMidiChannel*)p)->cb_button(); }
+void geMidiChannel::cb_openMenu(Fl_Widget* v, void* p) { ((geMidiChannel*)p)->cb_openMenu(); }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void geMidiChannel::__cb_button()
+void geMidiChannel::cb_button()
 {
 	if (button->value())
 		glue_keyPress(ch, Fl::event_ctrl(), Fl::event_shift());
@@ -214,7 +221,7 @@ void geMidiChannel::__cb_button()
 /* -------------------------------------------------------------------------- */
 
 
-void geMidiChannel::__cb_openMenu()
+void geMidiChannel::cb_openMenu()
 {
 	Fl_Menu_Item rclick_menu[] = {
 		{"Edit actions...", 0, menuCallback, (void*) Menu::EDIT_ACTIONS},
@@ -230,6 +237,7 @@ void geMidiChannel::__cb_openMenu()
 			{"Large",   0, menuCallback, (void*) Menu::RESIZE_H3},
 			{"X-Large", 0, menuCallback, (void*) Menu::RESIZE_H4},
 			{0},
+		{"Rename channel",  0, menuCallback, (void*) Menu::RENAME_CHANNEL},
 		{"Clone channel",  0, menuCallback, (void*) Menu::CLONE_CHANNEL},
 		{"Delete channel", 0, menuCallback, (void*) Menu::DELETE_CHANNEL},
 		{0}
@@ -240,13 +248,13 @@ void geMidiChannel::__cb_openMenu()
 	if (!ch->hasActions)
 		rclick_menu[(int)Menu::CLEAR_ACTIONS].deactivate();
 
-	Fl_Menu_Button *b = new Fl_Menu_Button(0, 0, 100, 50);
+	Fl_Menu_Button* b = new Fl_Menu_Button(0, 0, 100, 50);
 	b->box(G_CUSTOM_BORDER_BOX);
 	b->textsize(G_GUI_FONT_SIZE_BASE);
 	b->textcolor(G_COLOR_LIGHT_2);
 	b->color(G_COLOR_GREY_2);
 
-	const Fl_Menu_Item *m = rclick_menu->popup(Fl::event_x(), Fl::event_y(), 0, 0, b);
+	const Fl_Menu_Item* m = rclick_menu->popup(Fl::event_x(), Fl::event_y(), 0, 0, b);
 	if (m)
 		m->do_callback(this, m->user_data());
 	return;
@@ -278,22 +286,29 @@ void geMidiChannel::reset()
 
 void geMidiChannel::update()
 {
-	if (((MidiChannel*) ch)->midiOut) {
-		char tmp[32];
-		sprintf(tmp, "-- MIDI (channel %d) --", ((MidiChannel*) ch)->midiOutChan+1);
-		mainButton->copy_label(tmp);
-	}
+	const MidiChannel* mch = static_cast<const MidiChannel*>(ch);
+
+	string label; 
+	if (mch->getName().empty())
+		label = "-- MIDI --";
 	else
-		mainButton->label("-- MIDI --");
+		label = mch->getName().c_str();
 
-	vol->value(ch->volume);
-	mute->value(ch->mute);
-	solo->value(ch->solo);
+	if (mch->midiOut) 
+		label += " (ch " + gu_iToString(mch->midiOutChan + 1) + " out)";
 
-	mainButton->setKey(ch->key);
+	mainButton->label(label.c_str());
+
+	vol->value(mch->volume);
+	mute->value(mch->mute);
+	solo->value(mch->solo);
+
+	mainButton->setKey(mch->key);
+
+	arm->value(mch->isArmed());
 
 #ifdef WITH_VST
-	fx->status = ch->plugins.size() > 0;
+	fx->status = mch->plugins.size() > 0;
 	fx->redraw();
 #endif
 }
@@ -319,23 +334,4 @@ void geMidiChannel::resize(int X, int Y, int W, int H)
 #endif
 
 	packWidgets();
-}
-
-
-/* -------------------------------------------------------------------------- */
-/* -------------------------------------------------------------------------- */
-/* -------------------------------------------------------------------------- */
-
-
-geMidiChannelButton::geMidiChannelButton(int x, int y, int w, int h, const char *l)
-	: geChannelButton(x, y, w, h, l) {}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-int geMidiChannelButton::handle(int e)
-{
-	// MIDI drag-n-drop does nothing so far.
-	return geButton::handle(e);
-}
+}
\ No newline at end of file
