@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -39,6 +39,7 @@
 #include "../../../dialogs/gd_mainWindow.h"
 #include "../../../dialogs/gd_keyGrabber.h"
 #include "../../../dialogs/sampleEditor.h"
+#include "../../../dialogs/channelNameInput.h"
 #include "../../../dialogs/gd_actionEditor.h"
 #include "../../../dialogs/gd_warnings.h"
 #include "../../../dialogs/browser/browserSave.h"
@@ -60,7 +61,7 @@
 extern gdMainWindow* G_MainWin;
 
 
-using namespace giada::m;
+using namespace giada;
 
 
 namespace
@@ -87,6 +88,7 @@ enum class Menu
 	RESIZE_H3,
 	RESIZE_H4,
 	__END_RESIZE_SUBMENU__,
+	RENAME_CHANNEL,
 	CLONE_CHANNEL,
 	FREE_CHANNEL,
 	DELETE_CHANNEL
@@ -107,16 +109,16 @@ void menuCallback(Fl_Widget* w, void* v)
 			break;
 		}
 		case Menu::LOAD_SAMPLE: {
-			gdWindow *w = new gdBrowserLoad(conf::browserX, conf::browserY,
-				conf::browserW, conf::browserH, "Browse sample",
-				conf::samplePath.c_str(), glue_loadSample, gch->ch);
+			gdWindow *w = new gdBrowserLoad(m::conf::browserX, m::conf::browserY,
+				m::conf::browserW, m::conf::browserH, "Browse sample",
+				m::conf::samplePath.c_str(), glue_loadSample, gch->ch);
 			gu_openSubWindow(G_MainWin, w, WID_FILE_BROWSER);
 			break;
 		}
 		case Menu::EXPORT_SAMPLE: {
-			gdWindow *w = new gdBrowserSave(conf::browserX, conf::browserY,
-				conf::browserW, conf::browserH, "Save sample",
-				conf::samplePath.c_str(), "", glue_saveSample, gch->ch);
+			gdWindow *w = new gdBrowserSave(m::conf::browserX, m::conf::browserY,
+				m::conf::browserW, m::conf::browserH, "Save sample",
+				m::conf::samplePath.c_str(), "", glue_saveSample, gch->ch);
 			gu_openSubWindow(G_MainWin, w, WID_FILE_BROWSER);
 			break;
 		}
@@ -146,19 +148,19 @@ void menuCallback(Fl_Widget* w, void* v)
 		case Menu::__END_RESIZE_SUBMENU__:
 			break;
 		case Menu::CLEAR_ACTIONS_ALL: {
-			glue_clearAllActions(gch);
+			c::recorder::clearAllActions(gch);
 			break;
 		}
 		case Menu::CLEAR_ACTIONS_MUTE: {
-			glue_clearMuteActions(gch);
+			c::recorder::clearMuteActions(gch);
 			break;
 		}
 		case Menu::CLEAR_ACTIONS_VOLUME: {
-			glue_clearVolumeActions(gch);
+			c::recorder::clearVolumeActions(gch);
 			break;
 		}
 		case Menu::CLEAR_ACTIONS_START_STOP: {
-			glue_clearStartStopActions(gch);
+			c::recorder::clearStartStopActions(gch);
 			break;
 		}
 		case Menu::RESIZE_H1: {
@@ -185,6 +187,10 @@ void menuCallback(Fl_Widget* w, void* v)
 			glue_cloneChannel(gch->ch);
 			break;
 		}
+		case Menu::RENAME_CHANNEL: {
+			gu_openSubWindow(G_MainWin, new gdChannelNameInput(gch->ch), WID_SAMPLE_NAME);
+			break;
+		}
 		case Menu::FREE_CHANNEL: {
 			glue_freeChannel(gch->ch);
 			break;
@@ -286,7 +292,7 @@ void geSampleChannel::__cb_openMenu()
 	/* If you're recording (input or actions) no menu is allowed; you can't do
 	anything, especially deallocate the channel */
 
-	if (mixer::recording || recorder::active)
+	if (m::mixer::recording || m::recorder::active)
 		return;
 
 	Fl_Menu_Item rclick_menu[] = {
@@ -311,6 +317,7 @@ void geSampleChannel::__cb_openMenu()
 			{"Large",   0, menuCallback, (void*) Menu::RESIZE_H3},
 			{"X-Large", 0, menuCallback, (void*) Menu::RESIZE_H4},
 			{0},
+		{"Rename channel", 0, menuCallback, (void*) Menu::RENAME_CHANNEL},
 		{"Clone channel",  0, menuCallback, (void*) Menu::CLONE_CHANNEL},
 		{"Free channel",   0, menuCallback, (void*) Menu::FREE_CHANNEL},
 		{"Delete channel", 0, menuCallback, (void*) Menu::DELETE_CHANNEL},
@@ -321,11 +328,13 @@ void geSampleChannel::__cb_openMenu()
 		rclick_menu[(int) Menu::EXPORT_SAMPLE].deactivate();
 		rclick_menu[(int) Menu::EDIT_SAMPLE].deactivate();
 		rclick_menu[(int) Menu::FREE_CHANNEL].deactivate();
+		rclick_menu[(int) Menu::RENAME_CHANNEL].deactivate();
 	}
 
 	if (!ch->hasActions)
 		rclick_menu[(int) Menu::CLEAR_ACTIONS].deactivate();
 
+
 	/* No 'clear start/stop actions' for those channels in loop mode: they cannot
 	have start/stop actions. */
 
@@ -350,7 +359,7 @@ void geSampleChannel::__cb_openMenu()
 
 void geSampleChannel::__cb_readActions()
 {
-	glue_startStopReadingRecs(static_cast<SampleChannel*>(ch));
+	glue_toggleReadingRecs(static_cast<SampleChannel*>(ch));
 }
 
 
@@ -365,10 +374,10 @@ void geSampleChannel::refresh()
 	setColorsByStatus(ch->status, ch->recStatus);
 
 	if (static_cast<SampleChannel*>(ch)->wave != nullptr) {
-		if (mixer::recording && ch->armed)
+		if (m::mixer::recording && ch->isArmed())
 			mainButton->setInputRecordMode();
-		if (recorder::active) {
-			if (recorder::canRec(ch, clock::isRunning(), mixer::recording))
+		if (m::recorder::active) {
+			if (m::recorder::canRec(ch, m::clock::isRunning(), m::mixer::recording))
 				mainButton->setActionRecordMode();
 		}
 		status->redraw(); // status invisible? sampleButton too (see below)
@@ -394,9 +403,9 @@ void geSampleChannel::reset()
 
 void geSampleChannel::update()
 {
-	/* update sample button's label */
+	const SampleChannel* sch = static_cast<const SampleChannel*>(ch);
 
-	switch (ch->status) {
+	switch (sch->status) {
 		case STATUS_EMPTY:
 			mainButton->label("-- no sample --");
 			break;
@@ -405,34 +414,35 @@ void geSampleChannel::update()
 			mainButton->label("* file not found! *");
 			break;
 		default:
-			mainButton->label(static_cast<SampleChannel*>(ch)->wave->getName().c_str());
+			if (sch->getName().empty())
+				mainButton->label(sch->wave->getBasename(false).c_str());
+			else
+				mainButton->label(sch->getName().c_str());
 			break;
 	}
 
-	/* update channels. If you load a patch with recorded actions, the 'R'
-	 * button must be shown. Moreover if the actions are active, the 'R'
-	 * button must be activated accordingly. */
+	/* Update channels. If you load a patch with recorded actions, the 'R' button 
+	must be shown. Moreover if the actions are active, the 'R' button must be 
+	activated accordingly. */
 
-	if (ch->hasActions)
+	if (sch->hasActions)
 		showActionButton();
 	else
 		hideActionButton();
 
-	/* updates modebox */
-
-	modeBox->value(static_cast<SampleChannel*>(ch)->mode);
+	modeBox->value(sch->mode);
 	modeBox->redraw();
 
-	/* update volumes+mute+solo */
+	vol->value(sch->volume);
+	mute->value(sch->mute);
+	solo->value(sch->solo);
 
-	vol->value(ch->volume);
-	mute->value(ch->mute);
-	solo->value(ch->solo);
+	mainButton->setKey(sch->key);
 
-	mainButton->setKey(ch->key);
+	arm->value(sch->isArmed());
 
 #ifdef WITH_VST
-	fx->status = ch->plugins.size() > 0;
+	fx->status = sch->plugins.size() > 0;
 	fx->redraw();
 #endif
 }
