@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -37,11 +37,11 @@
 #include "sampleChannelButton.h"
 
 
-extern gdMainWindow *G_MainWin;
+extern gdMainWindow* G_MainWin;
 
 
 geSampleChannelButton::geSampleChannelButton(int x, int y, int w, int h,
-	const char *l)
+	const char* l)
 	: geChannelButton(x, y, w, h, l)
 {
 }
@@ -61,9 +61,9 @@ int geSampleChannelButton::handle(int e)
 			break;
 		}
 		case FL_PASTE: {
-			geSampleChannel *gch = static_cast<geSampleChannel*>(parent());
-			SampleChannel   *ch  = static_cast<SampleChannel*>(gch->ch);
-			int result = glue_loadChannel(ch, gu_trim(gu_stripFileUrl(Fl::event_text())).c_str());
+			geSampleChannel* gch = static_cast<geSampleChannel*>(parent());
+			SampleChannel*   ch  = static_cast<SampleChannel*>(gch->ch);
+			int result = glue_loadChannel(ch, gu_trim(gu_stripFileUrl(Fl::event_text())));
 			if (result != G_RES_OK)
 				G_MainWin->keyboard->printChannelMessage(result);
 			ret = 1;
