@@ -4,7 +4,7 @@
 *
 * -----------------------------------------------------------------------------
 *
-* Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+* Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
 *
 * This file is part of Giada - Your Hardcore Loopmachine.
 *
@@ -35,7 +35,7 @@
 #include "../../elems/basics/statusButton.h"
 #include "../../elems/basics/dial.h"
 #include "../../dialogs/gd_mainWindow.h"
-#include "../../dialogs/gd_pluginList.h"
+#include "../../dialogs/pluginList.h"
 #include "mainIO.h"
 
 
