@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -25,19 +25,23 @@
  * -------------------------------------------------------------------------- */
 
 
+#include "../../utils/string.h"
+#include "../dialogs/midiIO/midiInputBase.h"
 #include "basics/boxtypes.h"
 #include "basics/button.h"
 #include "basics/box.h"
 #include "midiLearner.h"
 
 
+using std::string;
 using namespace giada::m;
 
 
-geMidiLearner::geMidiLearner(int X, int Y, int W, const char *l,
-  kernelMidi::cb_midiLearn *cb, uint32_t *param)
+geMidiLearner::geMidiLearner(int X, int Y, int W, const char* l,
+  midiDispatcher::cb_midiLearn* cb, uint32_t* param, Channel* ch)
 	: Fl_Group(X, Y, W, 20),
 		callback(cb),
+		ch      (ch),
 		param   (param)
 {
 	begin();
@@ -64,12 +68,15 @@ geMidiLearner::geMidiLearner(int X, int Y, int W, const char *l,
 
 void geMidiLearner::updateValue()
 {
-	char buf[16];
-	if (*param != 0x0)
-		snprintf(buf, 9, "0x%X", *param);
+	string tmp;
+	if (*param != 0x0) {
+		tmp = "0x" + gu_iToString(*param, true); // true: hex mode
+		tmp.pop_back();  // Remove last two digits, useless in MIDI messages
+		tmp.pop_back();  // Remove last two digits, useless in MIDI messages
+	}
 	else
-		snprintf(buf, 16, "(not set)");
-	value->copy_label(buf);
+		tmp = "(not set)";
+	value->copy_label(tmp.c_str());
 	button->value(0);
 }
 
@@ -77,14 +84,14 @@ void geMidiLearner::updateValue()
 /* -------------------------------------------------------------------------- */
 
 
-void geMidiLearner::cb_button(Fl_Widget *v, void *p) { ((geMidiLearner*)p)->__cb_button(); }
-void geMidiLearner::cb_value(Fl_Widget *v, void *p) { ((geMidiLearner*)p)->__cb_value(); }
+void geMidiLearner::cb_button(Fl_Widget* v, void* p) { ((geMidiLearner*)p)->cb_button(); }
+void geMidiLearner::cb_value(Fl_Widget* v, void* p) { ((geMidiLearner*)p)->cb_value(); }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void geMidiLearner::__cb_value()
+void geMidiLearner::cb_value()
 {
 	if (Fl::event_button() == FL_RIGHT_MOUSE) {
 		*param = 0x0;
@@ -97,13 +104,14 @@ void geMidiLearner::__cb_value()
 /* -------------------------------------------------------------------------- */
 
 
-void geMidiLearner::__cb_button()
+void geMidiLearner::cb_button()
 {
 	if (button->value() == 1) {
-		cbData.window  = (gdMidiInput*) parent();  // parent = gdMidiInput
+		cbData.window  = static_cast<gdMidiInputBase*>(parent()); // parent = gdMidiInput
 		cbData.learner = this;
-		kernelMidi::startMidiLearn(callback, (void*)&cbData);
+		cbData.channel = ch;
+		midiDispatcher::startMidiLearn(callback, (void*)&cbData);
 	}
 	else
-		kernelMidi::stopMidiLearn();
+		midiDispatcher::stopMidiLearn();
 }
